import {
	Panel,
	PanelBody,
	ToggleControl,
	SelectControl,
} from '@wordpress/components';
import { __ } from '@wordpress/i18n';
import {
	InspectorControls,
	store as blockEditorStore,
} from '@wordpress/block-editor';
import { useSelect } from '@wordpress/data';

export default function Inspector(props) {
	const {
		showExcerpt,
		showThumbnail,
		setAttributes,
		thumbnailSize,
		orderBy,
		htmlTag,
	} = props;

	const imageSizes = useSelect((select) => {
		const array = select(blockEditorStore)
			.getSettings()
			.imageSizes.map((image) => {
				return {
					value: image.slug,
					label: image.name,
				};
			});
		return array;
	});

	return (
		<InspectorControls>
			<Panel>
				<PanelBody>
					<ToggleControl
						label={__("Afficher l'extrait", 'bsw-blocks')}
						checked={showExcerpt}
						onChange={(showExcerpt) =>
							setAttributes({ showExcerpt })
						}
					/>
					<ToggleControl
						label={__("Afficher l'image", 'bsw-blocks')}
						checked={showThumbnail}
						onChange={(showThumbnail) =>
							setAttributes({ showThumbnail })
						}
					/>
					{showThumbnail && (
						<SelectControl
							value={thumbnailSize}
							options={imageSizes}
							label={__("Taille de l'image", 'bsw-blocks')}
							onChange={(newThumbnailSize) =>
								setAttributes({
									thumbnailSize: newThumbnailSize,
								})
							}
						/>
					)}

					<SelectControl
						value={orderBy}
						options={[
							{ value: 'title', label: 'Titre' },
							{ value: 'date', label: 'Date' },
							{ value: 'menu_order', label: 'Ordre du menu' },
						]}
						label={__('Ordonner par', 'bsw-blocks')}
						onChange={(newOrderby) =>
							setAttributes({
								orderBy: newOrderby,
							})
						}
					/>
					<SelectControl
						value={htmlTag}
						options={[
							{ value: 'p', label: __('p') },
							{ value: 'h1', label: __('h1') },
							{ value: 'h2', label: __('h2') },
							{ value: 'h3', label: __('h3') },
							{ value: 'h4', label: __('h4') },
							{ value: 'h5', label: __('h5') },
							{ value: 'h6', label: __('h6') },
						]}
						label={__(
							'Balise Html pour le titre des articles',
							'bsw-blocks'
						)}
						onChange={(htmlTag) => setAttributes({ htmlTag })}
					/>
				</PanelBody>
			</Panel>
		</InspectorControls>
	);
}
