/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';
import { Fragment } from '@wordpress/element';
import Inspector from './inspector';
import Block from './block';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @param {Object} props
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit(props) {
	const { attributes, setAttributes } = props;
	const { postsIds, thumbnailSize, showThumbnail, showExcerpt } = attributes;

	return (
		<Fragment>
			<Inspector
				{...{
					postsIds,
					setAttributes,
					thumbnailSize,
					showThumbnail,
					showExcerpt,
				}}
			/>
			<Block
				{...{
					postsIds,
					setAttributes,
					thumbnailSize,
					showThumbnail,
					showExcerpt,
				}}
			/>
		</Fragment>
	);
}
