import {
	// eslint-disable-next-line @wordpress/no-unsafe-wp-apis
	__experimentalNumberControl as NumberControl,
	Panel,
	PanelBody,
	TextControl,
	ToggleControl,
} from '@wordpress/components';
import { InspectorControls } from '@wordpress/block-editor';
import { __ } from '@wordpress/i18n';

export default function Inspector(props) {
	const {
		interval,
		perPage,
		perMove,
		autoplay,
		showArrows,
		showPagination,
		setAttributes,
		padding,
		perMoveMobile,
		perPageMobile,
		paddingMobile,
		margin,
	} = props;

	return (
		<InspectorControls>
			<Panel>
				<PanelBody
					title={__('Options slider', 'bsw-blocks')}
					initialOpen
				>
					<ToggleControl
						label={__('Défilement automatique', 'bsw-blocks')}
						checked={autoplay}
						onChange={(autoplay) => setAttributes({ autoplay })}
					/>
					<ToggleControl
						label={__('Afficher les flèches', 'bsw-blocks')}
						checked={showArrows}
						onChange={(showArrows) => setAttributes({ showArrows })}
					/>

					<ToggleControl
						label={__('Afficher la pagination', 'bsw-blocks')}
						checked={showPagination}
						onChange={(showPagination) =>
							setAttributes({ showPagination })
						}
					/>
					<NumberControl
						label={__(
							'Intervalle de défilement des slides (ms)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={50000}
						minimum={1000}
						value={interval}
						onChange={(interval) => setAttributes({ interval })}
						step={100}
					/>

					<TextControl
						label={__('Espacement des slides', 'bsw-blocks')}
						value={margin}
						onChange={(margin) => setAttributes({ margin })}
					/>

					<NumberControl
						label={__(
							'Nombre de slides par page (Desktop)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perPage}
						onChange={(perPage) => setAttributes({ perPage })}
						step={1}
					/>

					<NumberControl
						label={__('Nombre de slides (Desktop)', 'bsw-blocks')}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perMove}
						onChange={(perMove) => setAttributes({ perMove })}
						step={1}
					/>
					<TextControl
						label={__('Padding (Desktop)', 'bsw-blocks')}
						value={padding}
						onChange={(padding) => setAttributes({ padding })}
					/>
				</PanelBody>
				<PanelBody
					title={__('Options pour mobile du slider', 'bsw-blocks')}
					initialOpen
				>
					<NumberControl
						label={__(
							'Nombre de slides par page (Mobile)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perPageMobile}
						onChange={(perPageMobile) =>
							setAttributes({ perPageMobile })
						}
						step={1}
					/>
					<NumberControl
						label={__('Nombre de slides (Mobile)', 'bsw-blocks')}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perMoveMobile}
						onChange={(perMoveMobile) =>
							setAttributes({ perMoveMobile })
						}
						step={1}
					/>
					<TextControl
						label={__('Padding (Mobile)', 'bsw-blocks')}
						value={paddingMobile}
						onChange={(paddingMobile) =>
							setAttributes({ paddingMobile })
						}
					/>
				</PanelBody>
			</Panel>
		</InspectorControls>
	);
}
