/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { InnerBlocks, useBlockProps } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @param {Object} props
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */
export default function save(props) {
	const { attributes } = props;
	const {
		interval,
		perPage,
		perMove,
		autoplay,
		showArrows,
		showPagination,
		padding,
		perMoveMobile,
		perPageMobile,
		paddingMobile,
		blockId,
		margin,
	} = attributes;

	const blockProps = useBlockProps.save({
		className: 'splide',
		id: `splide-${blockId}`,
	});
	return (
		<div
			{...blockProps}
			data-autoplay={autoplay}
			data-interval={interval}
			data-per_page={perPage}
			data-per_page_mobile={perPageMobile}
			data-per_move={perMove}
			data-per_move_mobile={perMoveMobile}
			data-arrows={showArrows}
			data-pagination={showPagination}
			data-padding={padding}
			data-padding_mobile={paddingMobile}
			data-blockId={blockId}
			data-margin={margin}
		>
			<div className={'splide__track'}>
				<ul className={'splide__list'}>
					<InnerBlocks.Content />
				</ul>
			</div>
		</div>
	);
}
