import {
	InspectorControls,
	store as blockEditorStore,
} from '@wordpress/block-editor';
import { __ } from '@wordpress/i18n';
import {
	__experimentalNumberControl as NumberControl,
	ToggleControl,
	Panel,
	PanelBody,
	SelectControl,
	TextControl,
} from '@wordpress/components';

import { useSelect } from '@wordpress/data';

export default function Inspector(props) {
	const {
		idTagName,
		idCategorieName,
		postType,
		interval,
		orderBy,
		showThumbnail,
		showExcerpt,
		showTags,
		showCategories,
		perPage,
		nombrePosts,
		perMove,
		autoplay,
		showArrows,
		showPagination,
		setAttributes,
		tagsList,
		categoriesList,
		allPostType,
		thumbnailSize,
		padding,
		perMoveMobile,
		perPageMobile,
		paddingMobile,
		excludeCurrentPage,
		readMore,
		linkTitle,
		margin,
	} = props;

	const imageSizes = useSelect((select) => {
		return select(blockEditorStore)
			.getSettings()
			.imageSizes.map((image) => {
				return {
					value: image.slug,
					label: image.name,
				};
			});
	});

	//Création d'un tableau avec les tags et leur ID
	const tagArrayId = useSelect((select) => {
		const allTags = select('core').getEntityRecords(
			'taxonomy',
			'post_tag',
			{
				per_page: -1,
			}
		);
		const arrayNameId = [];

		if (allTags) {
			allTags.forEach(function (element) {
				const array = [
					element.id,
					element.name,
					element.link,
					element.slug,
				];
				arrayNameId.push(array);
			});
		}
		return arrayNameId;
	});

	let i = -1;

	while (++i < tagArrayId.length) {
		tagsList[i] = tagArrayId[i];
	}

	//Fonction qui permet de mettre en majuscule la 1ère lettre de l'expression injecté
	function capitalizeFirstLetter(string) {
		return string.charAt(0).toUpperCase() + string.slice(1);
	}

	//Initialisation d'un tableau d'objets des options de notre SelectControl pour le choix de notre Tag
	const options = [
		{
			value: undefined,
			label: 'Aucun',
		},
	];

	//On injecte à l'aide d'une boucle les données du tableau dans les options de notre SelectControl correspondant au choix de nos tags
	if (tagArrayId) {
		tagArrayId.forEach(function (value) {
			const object = {
				value: value[0],
				label: capitalizeFirstLetter(value[1]),
			};
			options.push(object);
		});
	}

	//Même partie sur les catégories

	//Création d'un tableau avec les categories et leur ID
	const categorieArrayId = useSelect((select) => {
		const allCategories = select('core').getEntityRecords(
			'taxonomy',
			postType === 'tribe_events' ? 'tribe_events_cat' : 'category',
			{
				per_page: -1,
			}
		);
		const arrayNameId = [];

		if (allCategories) {
			allCategories.forEach(function (element) {
				const array = [element.id, element.name, element.link];
				arrayNameId.push(array);
			});
		}
		return arrayNameId;
	});

	let z = -1;

	while (++z < categorieArrayId.length) {
		categoriesList[z] = categorieArrayId[z];
	}

	//Initialisation d'un tableau d'objets des options de notre SelectControl pour le choix de notre categorie
	const optionsCategories = [
		{
			value: undefined,
			label: 'Aucun',
		},
	];

	//On injecte à l'aide d'une boucle les données du tableau dans les options de notre SelectControl correspondant au choix de nos categories
	if (categorieArrayId) {
		categorieArrayId.forEach(function (value) {
			const object = {
				value: value[0],
				label: capitalizeFirstLetter(value[1]),
			};
			optionsCategories.push(object);
		});
	}

	// Récupération des type de post
	const postTypes = useSelect((select) => {
		const { getPostTypes } = select('core');
		const excludedPostTypes = ['attachment'];

		const filteredPostTypes = getPostTypes({ per_page: -1 })?.filter(
			({ viewable, slug }) =>
				viewable && !excludedPostTypes.includes(slug)
		);
		const arrayPostType = [];

		if (filteredPostTypes) {
			filteredPostTypes.forEach((element) =>
				arrayPostType.push(element.slug)
			);
		}
		let i = -1;
		while (++i < arrayPostType.length) {
			allPostType[i] = arrayPostType[i];
		}
		return arrayPostType;
	}, []);

	const optionsPostType = [
		{
			value: 'any',
			label: 'Tous',
		},
	];
	//Boucle pour créer les postTypes
	postTypes.forEach(function (element) {
		const object = {
			value: element,
			label:
				element === 'tribe_events'
					? 'Événements'
					: capitalizeFirstLetter(element),
		};
		optionsPostType.push(object);
	});

	return (
		<InspectorControls>
			<Panel>
				<PanelBody title={__('General', 'bsw-blocks')} initialOpen>
					<ToggleControl
						label={__("Afficher l'image", 'bsw-blocks')}
						checked={showThumbnail}
						onChange={(showThumbnail) =>
							setAttributes({ showThumbnail })
						}
					/>
					{showThumbnail && (
						<SelectControl
							value={thumbnailSize}
							options={imageSizes}
							label={__("Taille de l'image", 'bsw-blocks')}
							onChange={(newThumbnailSize) =>
								setAttributes({
									thumbnailSize: newThumbnailSize,
								})
							}
						/>
					)}
					<ToggleControl
						label={__('Exclure la page courante', 'bsw-blocks')}
						checked={excludeCurrentPage}
						onChange={(excludeCurrentPage) => {
							setAttributes({ excludeCurrentPage });
							setAttributes({ tagsListOfCurrentPost: [] });
						}}
					/>
					{postType !== 'temoignage' && (
						<ToggleControl
							label={__('Afficher la description', 'bsw-blocks')}
							checked={showExcerpt}
							onChange={(showExcerpt) =>
								setAttributes({ showExcerpt })
							}
						/>
					)}

					<ToggleControl
						label={__('Afficher les tags', 'bsw-blocks')}
						checked={showTags}
						onChange={(showTags) => setAttributes({ showTags })}
					/>
					{postType === 'temoignage' && (
						<ToggleControl
							label={__('Afficher les categories', 'bsw-blocks')}
							checked={showCategories}
							onChange={(showCategories) =>
								setAttributes({ showCategories })
							}
						/>
					)}

					{postType !== 'temoignage' && (
						<ToggleControl
							label={__(
								'Afficher un lien lire la suite',
								'bsw-blocks'
							)}
							checked={readMore}
							onChange={(readMore) => setAttributes({ readMore })}
						/>
					)}

					{readMore && (
						<TextControl
							label={__('Intitulé du lien', 'bsw-blocks')}
							value={linkTitle}
							onChange={(linkTitle) =>
								setAttributes({ linkTitle })
							}
						/>
					)}
				</PanelBody>
				<PanelBody title={__('Réglages', 'bsw-blocks')} initialOpen>
					<SelectControl
						value={postType}
						options={optionsPostType}
						label={__('Type de publications', 'scrollable-gallery')}
						onChange={(newPostType) => {
							setAttributes({ postType: newPostType });
							setAttributes({ idTagName: undefined });
							setAttributes({ idCategorieName: undefined });
						}}
					/>
					<NumberControl
						label={__('Nombre de publications', 'bsw-blocks')}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={nombrePosts}
						onChange={(nombrePosts) =>
							setAttributes({ nombrePosts })
						}
						step={1}
					/>

					<SelectControl
						label={__('Ordonner par', 'bsw-blocks')}
						options={[
							{ value: 'title', label: 'Titre' },
							{ value: 'rand', label: 'Aléatoire' },
							{ value: 'date', label: 'Date' },
							{ value: 'menu_order', label: 'Ordre du menu' },
						]}
						checked={orderBy}
						onChange={(orderBy) => setAttributes({ orderBy })}
					/>
				</PanelBody>
				<PanelBody title={__('Filtre', 'bsw-blocks')} initialOpen>
					<SelectControl
						value={idTagName}
						options={options}
						label={__('Tags', 'scrollable-gallery')}
						onChange={(newIdTagName) =>
							setAttributes({ idTagName: newIdTagName })
						}
					/>
					{postType !== 'tribe_events' && (
						<SelectControl
							value={idCategorieName}
							options={optionsCategories}
							label={__('Categories', 'scrollable-gallery')}
							onChange={(newIdCategorieName) =>
								setAttributes({
									idCategorieName: newIdCategorieName,
								})
							}
						/>
					)}
					{postType === 'tribe_events' && (
						<SelectControl
							value={idCategorieName}
							options={optionsCategories}
							label={__('Categories', 'scrollable-gallery')}
							onChange={(newIdCategorieName) =>
								setAttributes({
									idCategorieName: newIdCategorieName,
								})
							}
						/>
					)}
				</PanelBody>
				<PanelBody
					title={__('Options slider', 'bsw-blocks')}
					initialOpen
				>
					<ToggleControl
						label={__('Défilement automatique', 'bsw-blocks')}
						checked={autoplay}
						onChange={(autoplay) => setAttributes({ autoplay })}
					/>
					<ToggleControl
						label={__('Afficher les flèches', 'bsw-blocks')}
						checked={showArrows}
						onChange={(showArrows) => setAttributes({ showArrows })}
					/>

					<ToggleControl
						label={__('Afficher la pagination', 'bsw-blocks')}
						checked={showPagination}
						onChange={(showPagination) =>
							setAttributes({ showPagination })
						}
					/>
					<NumberControl
						label={__(
							'Intevalle de défilement des slides (ms)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={50000}
						minimum={1000}
						value={interval}
						onChange={(interval) => setAttributes({ interval })}
						step={100}
					/>

					<TextControl
						label={__('Espacement des slides', 'bsw-blocks')}
						value={margin}
						onChange={(margin) => setAttributes({ margin })}
					/>

					<NumberControl
						label={__(
							'Nombre de posts par page (Desktop)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perPage}
						onChange={(perPage) => setAttributes({ perPage })}
						step={1}
					/>

					<NumberControl
						label={__(
							'Nombre de diapositives (Desktop)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perMove}
						onChange={(perMove) => setAttributes({ perMove })}
						step={1}
					/>
					<TextControl
						label={__('Padding (Desktop)', 'bsw-blocks')}
						value={padding}
						onChange={(padding) => setAttributes({ padding })}
					/>
				</PanelBody>
				<PanelBody
					title={__('Options pour mobile du slider', 'bsw-blocks')}
					initialOpen
				>
					<NumberControl
						label={__(
							'Nombre de posts par page (Mobile)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perPageMobile}
						onChange={(perPageMobile) =>
							setAttributes({ perPageMobile })
						}
						step={1}
					/>
					<NumberControl
						label={__(
							'Nombre de diapositives (Mobile)',
							'bsw-blocks'
						)}
						isShiftStepEnabled={true}
						maximum={10}
						minimum={1}
						value={perMoveMobile}
						onChange={(perMoveMobile) =>
							setAttributes({ perMoveMobile })
						}
						step={1}
					/>
					<TextControl
						label={__('Padding (Mobile)', 'bsw-blocks')}
						value={paddingMobile}
						onChange={(paddingMobile) =>
							setAttributes({ paddingMobile })
						}
					/>
				</PanelBody>
			</Panel>
		</InspectorControls>
	);
}
