<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.bayard-service.com
 * @since             1.0.0
 * @package           Bsw_Didomi
 *
 * @wordpress-plugin
 * Plugin Name:       bsw-didomi
 * Plugin URI:        https://gitlab.bayard-service.com/wordpress/plugins/bsw-didomi
 * Description:       Gère l'affichage des vidéos Youtube, Vimeo, dailymotion, etc. en fonction de l'acceptation des cookies via Didomi
 * Version:           1.1.1
 * Author:            Bayard Service
 * Author URI:        https://www.bayard-service.com
 * Text Domain:       bsw-didomi
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('BSW_DIDOMI_VERSION', '1.0.0');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-bsw-didomi-activator.php
 */
function activate_bsw_didomi()
{
    require_once plugin_dir_path(__FILE__) . 'includes/class-bsw-didomi-activator.php';
    Bsw_Didomi_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-bsw-didomi-deactivator.php
 */
function deactivate_bsw_didomi()
{
    require_once plugin_dir_path(__FILE__) . 'includes/class-bsw-didomi-deactivator.php';
    Bsw_Didomi_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_bsw_didomi');
register_deactivation_hook(__FILE__, 'deactivate_bsw_didomi');

/**
 * The core plugin class that is used to define internationalization,
 * and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-bsw-didomi.php';

/**
 * Plugin Update Checker
 */
require_once('includes/plugin-update-checker/plugin-update-checker.php');

use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\Api;
use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\GitLabApi;
use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\PluginUpdateChecker;

$url_parts = parse_url(home_url());
$domain = $url_parts['host'];

$myUpdateChecker = new PluginUpdateChecker(
    new GitLabApi(
        'https://gitlab.bayard-service.com/wordpress/plugins/bsw-didomi/',
        'glpat--MKCqQco38yx3Qegwv1k',
        'plugins'
    ),
    __FILE__,
    'bsw-didomi'
);

$myUpdateChecker->getVcsApi()->enableReleaseAssets();

if ( strpos( $domain, 'pin3' ) !== false ) {
	$myUpdateChecker->setBranch( 'develop' );
	$myUpdateChecker->addFilter( 'vcs_update_detection_strategies', function ( $strategies ) {
		//Don't look for a release a tag or a "Stable tag" header in readme.txt.
		unset( $strategies[ Api::STRATEGY_LATEST_RELEASE ] );
		unset( $strategies[ Api::STRATEGY_LATEST_TAG ] );
		unset( $strategies[ Api::STRATEGY_STABLE_TAG ] );

		return $strategies;
	} );
}
if ( strpos( $domain, 'localhost' ) !== false ) {
	$myUpdateChecker->setBranch( 'develop' );
	$myUpdateChecker->addFilter( 'vcs_update_detection_strategies', function ( $strategies ) {
		//Don't look for a release a tag or a "Stable tag" header in readme.txt.
		unset( $strategies[ Api::STRATEGY_LATEST_RELEASE ] );
		unset( $strategies[ Api::STRATEGY_LATEST_TAG ] );
		unset( $strategies[ Api::STRATEGY_STABLE_TAG ] );

		return $strategies;
	} );
}

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_bsw_didomi()
{

    $plugin = new Bsw_Didomi();
    $plugin->run();

}

run_bsw_didomi();